==> aws-java-sdk-datapipeline-1.10.16-sources.jar: com/amazonaws/services/datapipeline/model/TaskStatus.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.datapipeline.model;

/**
 * Task Status
 */
public enum TaskStatus {
    
    FINISHED("FINISHED"),
    FAILED("FAILED"),
    FALSE("FALSE");

    private String value;

    private TaskStatus(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return TaskStatus corresponding to the value
     */
    public static TaskStatus fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("FINISHED".equals(value)) {
            return TaskStatus.FINISHED;
        } else if ("FAILED".equals(value)) {
            return TaskStatus.FAILED;
        } else if ("FALSE".equals(value)) {
            return TaskStatus.FALSE;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-java-sdk-datapipeline-1.10.31-sources.jar: com/amazonaws/services/datapipeline/model/TaskStatus.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.datapipeline.model;

/**
 * 
 */
public enum TaskStatus {

    FINISHED("FINISHED"),
    FAILED("FAILED"),
    FALSE("FALSE");

    private String value;

    private TaskStatus(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return TaskStatus corresponding to the value
     */
    public static TaskStatus fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if ("FINISHED".equals(value)) {
            return FINISHED;
        } else if ("FAILED".equals(value)) {
            return FAILED;
        } else if ("FALSE".equals(value)) {
            return FALSE;
        } else {
            throw new IllegalArgumentException("Cannot create enum from "
                    + value + " value!");
        }
    }
}
